@@ -1,13 +1,13 @@
 
 class Product:
 
-    def __init__(self, uuid: str, name: str, image: str, category: str, task_uuid: str = "", tags: [str] = None,
+    def __init__(self, uuid: str, name: str, image: str, category: str, process_uuid: str = "", tags: [str] = None,
                  description: str = "", _type: str = ''):
         assert type(uuid) == str
         assert type(name) == str
         assert type(image) == str
         assert type(category) == str
-        assert type(task_uuid) == str
+        assert type(process_uuid) == str
         assert type(tags) == list or tags is None
         assert type(description) == str
 
@@ -16,7 +16,7 @@ class Product:
         self.name = name
         self.image = image
         self.category = category
-        self.task_uuid = task_uuid
+        self.process_uuid = process_uuid
         self.tags = tags if tags else []
         self.description = description
 
@@ -26,7 +26,7 @@ class Product:
                    and other.name == self.name \
                    and other.image == self.image \
                    and other.category == self.category \
-                   and other.task_uuid == self.task_uuid \
+                   and other.process_uuid == self.process_uuid \
                    and other.tags == self.tags \
                    and other.description == self.description
         return False
@@ -36,4 +36,4 @@ class Product:
 
     def __repr__(self):
         return f"<id={self.uuid},name={self.name},image={self.image},category={self.category}" \
-               f",task_uuid={self.task_uuid},tags={self.tags},description={self.description}>"
+               f",process_uuid={self.process_uuid},tags={self.tags},description={self.description}>"
