@@ -66,6 +66,20 @@ class Test(TestCase):
         expected, got = f'name={self.name}', f'{self.pose}'
         assert expected in got, f"Expected {expected} in got: {got}"
 
+    def test_pose_to_dict(self):
+        pose_dict = self.pose.to_dict()
+        expected = {'x': 1, 'y': 2, 'z': 3, 'rx': -1.1, 'ry': -1.2, 'rz': 1.3}
+        self.assertEqual(pose_dict, expected)
+
+    def test_pose_from_dict(self):
+        pose = Pose.from_dict({'x': 1, 'y': 2, 'z': 3, 'rx': -1.1, 'ry': -1.2, 'rz': 1.3})
+        expected = Pose(Vector3(1, 2, 3), Vector3(-1.1, -1.2, 1.3))
+        self.assertEqual(pose, expected)
+
+        pose = Pose.from_dict({'x': 1, 'y': 2, 'z': 3, 'rx': -1.1, 'ry': -1.2, 'rz': 1.3, 'name': 'waypoint'})
+        expected = Pose(Vector3(1, 2, 3), Vector3(-1.1, -1.2, 1.3), name='waypoint')
+        self.assertEqual(pose, expected)
+
     def test_poses(self):
         list_of_poses = [
             Pose(Vector3(1, 1, 1), Vector3(-1.1, -1.2, 1.3), "waypoint_1"),
